@@ -7,13 +7,15 @@
 
 #pragma once
 
-#include <Attribute>
-#include <Item>
+#include <Akonadi/Attribute>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Incidence>
 
 #include <QAbstractListModel>
 
+#include <memory>
+
 namespace Akonadi
 {
 }
@@ -61,10 +63,9 @@ Q_SIGNALS:
 
 private:
     Q_DECLARE_PRIVATE(IncidenceAttachmentModel)
-    IncidenceAttachmentModelPrivate *const d_ptr;
+    std::unique_ptr<IncidenceAttachmentModelPrivate> const d_ptr;
 
     Q_PRIVATE_SLOT(d_func(), void resetModel())
     Q_PRIVATE_SLOT(d_func(), void itemFetched(Akonadi::Item::List))
 };
 }
-
