@@ -18,6 +18,7 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KWordWrap>
+#include <kcalendarcore_version.h>
 
 #include <KLocalizedString>
 #include <QAbstractTextDocumentLayout>
@@ -583,7 +584,7 @@ int CalPrintPluginBase::drawHeader(QPainter &p, const QString &title, QDate mont
 
     drawShadedBox(p, BOX_BORDER_WIDTH, backColor, box);
 
-    const auto oldPen {p.pen()};
+    const auto oldPen{p.pen()};
     p.setPen(getTextColor(backColor));
 
     // prev month left, current month centered, next month right
@@ -636,10 +637,12 @@ void CalPrintPluginBase::drawSmallMonth(QPainter &p, QDate qd, QRect box)
     newFont.setPixelSize(cellHeight);
     p.setFont(newFont);
 
+    const QLocale locale;
+
     // draw the title
     QRect titleBox(box);
     titleBox.setHeight(p.fontMetrics().height());
-    p.drawText(titleBox, Qt::AlignTop | Qt::AlignHCenter, QLocale::system().monthName(month));
+    p.drawText(titleBox, Qt::AlignTop | Qt::AlignHCenter, locale.standaloneMonthName(month));
 
     // draw days of week
     QRect wdayBox(box);
@@ -647,10 +650,10 @@ void CalPrintPluginBase::drawSmallMonth(QPainter &p, QDate qd, QRect box)
     wdayBox.setHeight(int(2 * cellHeight) - int(cellHeight));
 
     for (int col = 0; col < 7; ++col) {
-        QString tmpStr = QLocale::system().dayName(monthDate2.dayOfWeek())[0].toUpper();
+        const auto dayLetter = locale.standaloneDayName(monthDate2.dayOfWeek(), QLocale::ShortFormat)[0].toUpper();
         wdayBox.setLeft(int(box.left() + col * cellWidth));
         wdayBox.setRight(int(box.left() + (col + 1) * cellWidth));
-        p.drawText(wdayBox, Qt::AlignCenter, tmpStr);
+        p.drawText(wdayBox, Qt::AlignCenter, dayLetter);
         monthDate2 = monthDate2.addDays(1);
     }
 
@@ -799,8 +802,7 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
         // Adapt start/end times to include complete events
         for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
             Q_ASSERT(event);
-            if (!event
-                || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+            if (!event || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
                 || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
                 continue;
             }
@@ -856,8 +858,7 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
     QList<CellItem *> cells;
 
     for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
-        if (!event
-            || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+        if (!event || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
             || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
             continue;
         }
@@ -936,7 +937,7 @@ void CalPrintPluginBase::drawAgendaItem(PrintCellItem *item,
             }
         }
         if (includeCategories && !event->categoriesStr().isEmpty()) {
-                str = i18nc("summary, categories", "%1, %2", str, event->categoriesStr());
+            str = i18nc("summary, categories", "%1, %2", str, event->categoriesStr());
         }
         if (includeDescription && !event->description().isEmpty()) {
             str += QLatin1Char('\n');
@@ -1160,7 +1161,7 @@ void CalPrintPluginBase::drawIncidence(QPainter &p,
     QFontMetrics fm = p.fontMetrics();
     const int borderWidth = p.pen().width() + 1;
 
-    QString firstLine {time};
+    QString firstLine{time};
     if (!firstLine.isEmpty()) {
         firstLine += QStringLiteral(" ");
     }
@@ -1259,19 +1260,14 @@ public:
     KCalendarCore::Event::Ptr event;
 };
 
-void CalPrintPluginBase::drawMonth(QPainter &p,
-                                   QDate dt,
-                                   QRect box,
-                                   int maxdays,
-                                   int subDailyFlags,
-                                   int holidaysFlags)
+void CalPrintPluginBase::drawMonth(QPainter &p, QDate dt, QRect box, int maxdays, int subDailyFlags, int holidaysFlags)
 {
     p.save();
     QRect subheaderBox(box);
     subheaderBox.setHeight(subHeaderHeight());
     QRect borderBox(box);
     borderBox.setTop(subheaderBox.bottom() + 1);
-    drawSubHeaderBox(p, QLocale::system().monthName(dt.month()), subheaderBox);
+    drawSubHeaderBox(p, QLocale().standaloneMonthName(dt.month()), subheaderBox);
     // correct for half the border width
     int correction = (BOX_BORDER_WIDTH /*-1*/) / 2;
     QRect daysBox(borderBox);
@@ -1354,8 +1350,7 @@ void CalPrintPluginBase::drawMonth(QPainter &p,
     QVector<MonthEventStruct> monthentries;
 
     for (const KCalendarCore::Event::Ptr &e : std::as_const(events)) {
-        if (!e
-            || (mExcludeConfidential && e->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+        if (!e || (mExcludeConfidential && e->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
             || (mExcludePrivate && e->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
             continue;
         }
@@ -1529,17 +1524,7 @@ void CalPrintPluginBase::drawMonthTable(QPainter &p,
                 darkbg = true;
             }
             QRect dayBox(coledges[col], rowedges[row], coledges[col + 1] - coledges[col], rowedges[row + 1] - rowedges[row]);
-            drawDayBox(p,
-                       monthDate,
-                       fromTime,
-                       toTime,
-                       dayBox,
-                       false,
-                       recurDaily,
-                       recurWeekly,
-                       singleLineLimit,
-                       includeDescription,
-                       includeCategories);
+            drawDayBox(p, monthDate, fromTime, toTime, dayBox, false, recurDaily, recurWeekly, singleLineLimit, includeDescription, includeCategories);
             if (darkbg) {
                 p.setBackground(back);
                 darkbg = false;
@@ -1681,7 +1666,7 @@ void CalPrintPluginBase::drawTodo(int &count,
         p.drawLine(center, bottom, center, to);
     }
 
-    int posSoFar = width;  // Position of leftmost optional field.
+    int posSoFar = width; // Position of leftmost optional field.
 
     // due date
     if (posDueDt >= 0 && todo->hasDueDate()) {
@@ -1721,7 +1706,7 @@ void CalPrintPluginBase::drawTodo(int &count,
     }
 
     // categories
-    QRect categoriesRect {0, 0, 0, 0};
+    QRect categoriesRect{0, 0, 0, 0};
     if (posCategories >= 0) {
         outStr = todo->categoriesStr();
         outStr.replace(QLatin1Char(','), QLatin1Char('\n'));
@@ -1798,7 +1783,11 @@ void CalPrintPluginBase::drawTodo(int &count,
     for (const KCalendarCore::Todo::Ptr &todo : std::as_const(t)) {
         tl.append(todo);
     }
+#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 95, 0)
     KCalendarCore::Todo::List sl = mCalendar->sortTodos(tl, sortField, sortDir);
+#else
+    KCalendarCore::Todo::List sl = mCalendar->sortTodos(std::move(tl), sortField, sortDir);
+#endif
 #endif
 
     int subcount = 0;
