@@ -37,16 +37,6 @@ class QMimeData;
 namespace CalendarSupport
 {
 class Calendar;
-/**
- * returns the incidence from an akonadi item, or a null pointer if the item has no such payload
- */
-CALENDARSUPPORT_EXPORT KCalendarCore::Incidence::Ptr incidence(const Akonadi::Item &item);
-
-/**
- * returns the event from an akonadi item, or a null pointer if the item has no such payload
- */
-CALENDARSUPPORT_EXPORT KCalendarCore::Event::Ptr event(const Akonadi::Item &item);
-
 /**
  * returns the event from an incidence, or a null pointer if the item has no such payload
  */
@@ -57,21 +47,11 @@ CALENDARSUPPORT_EXPORT KCalendarCore::Event::Ptr event(const KCalendarCore::Inci
  */
 CALENDARSUPPORT_EXPORT KCalendarCore::Incidence::List incidencesFromItems(const Akonadi::Item::List &items);
 
-/**
- * returns the todo from an akonadi item, or a null pointer if the item has no such payload
- */
-CALENDARSUPPORT_EXPORT KCalendarCore::Todo::Ptr todo(const Akonadi::Item &item);
-
 /**
  * returns the todo from an incidence, or a null pointer if the item has no such payload
  */
 CALENDARSUPPORT_EXPORT KCalendarCore::Todo::Ptr todo(const KCalendarCore::Incidence::Ptr &incidence);
 
-/**
- * returns the journal from an akonadi item, or a null pointer if the item has no such payload
- */
-CALENDARSUPPORT_EXPORT KCalendarCore::Journal::Ptr journal(const Akonadi::Item &item);
-
 /**
  * returns the journal from an incidence, or a null pointer if the item has no such payload
  */
@@ -138,11 +118,6 @@ CALENDARSUPPORT_EXPORT KCalendarCore::Todo::List todos(const QMimeData *mimeData
 
 CALENDARSUPPORT_EXPORT KCalendarCore::Incidence::List incidences(const QMimeData *mimeData);
 
-/**
- * creates mime data object for dragging an akonadi item containing an incidence
- */
-CALENDARSUPPORT_EXPORT QMimeData *createMimeData(const Akonadi::Item &item);
-
 /**
  * creates mime data object for dragging akonadi items containing an incidence
  */
@@ -152,12 +127,12 @@ CALENDARSUPPORT_EXPORT QMimeData *createMimeData(const Akonadi::Item::List &item
 /**
  * creates a drag object for dragging an akonadi item containing an incidence
  */
-CALENDARSUPPORT_EXPORT QDrag *createDrag(const Akonadi::Item &item, QWidget *parent);
+CALENDARSUPPORT_EXPORT QDrag *createDrag(const Akonadi::Item &item, QObject *parent);
 
 /**
  * creates a drag object for dragging akonadi items containing an incidence
  */
-CALENDARSUPPORT_EXPORT QDrag *createDrag(const Akonadi::Item::List &items, QWidget *parent);
+CALENDARSUPPORT_EXPORT QDrag *createDrag(const Akonadi::Item::List &items, QObject *parent);
 #endif
 /**
   Applies a filter to a list of items containing incidences.
@@ -190,14 +165,10 @@ itemsFromModel(const QAbstractItemModel *model, const QModelIndex &parentIndex =
 CALENDARSUPPORT_EXPORT Akonadi::Collection::List
 collectionsFromModel(const QAbstractItemModel *model, const QModelIndex &parentIndex = QModelIndex(), int start = 0, int end = -1);
 
-CALENDARSUPPORT_EXPORT Akonadi::Collection collectionFromIndex(const QModelIndex &index);
-
 CALENDARSUPPORT_EXPORT Akonadi::Collection::Id collectionIdFromIndex(const QModelIndex &index);
 
 CALENDARSUPPORT_EXPORT Akonadi::Collection::List collectionsFromIndexes(const QModelIndexList &indexes);
 
-CALENDARSUPPORT_EXPORT QString displayName(Akonadi::ETMCalendar *calendar, const Akonadi::Collection &coll);
-
 CALENDARSUPPORT_EXPORT QString subMimeTypeForIncidence(const KCalendarCore::Incidence::Ptr &incidence);
 
 /**
@@ -230,4 +201,3 @@ CALENDARSUPPORT_EXPORT bool mergeCalendar(const QString &srcFilename, const KCal
 
 CALENDARSUPPORT_EXPORT void createAlarmReminder(const KCalendarCore::Alarm::Ptr &alarm, KCalendarCore::IncidenceBase::IncidenceType type);
 }
-
